#
# spec file for package gops
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         google
%global repo            gops
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           gops
Version:        0.3.20
Release:        bp154.1.26
Summary:        A tool to list and diagnose Go processes currently running on your system
License:        BSD-3-Clause-Clear
Group:          System/Monitoring
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/v%{version}.tar.gz#/%{repo}-%{version}.tar.gz
BuildRequires:  golang-packaging
%{go_provides}

%description
gops is a command to list and diagnose Go processes currently running on your
system. For processes that starts the diagnostics agent, gops can report
additional information such as the current stack trace, Go version, memory stats,
etc. It is possible to use gops tool both in local and remote mode.

%prep
%setup -q -n %{repo}-%{version}

%build
%goprep %{provider_prefix}
go build \
   -mod=vendor \
   -v -p 4 -x \
%ifnarch ppc64 ppc64le riscv64
   -buildmode=pie \
%endif
   %{import_path}

%install
go install \
   -mod=vendor \
   -v -p 4 -x \
%ifnarch ppc64 ppc64le riscv64
   -buildmode=pie \
%endif
   %{import_path}
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}

%files
%{_bindir}/%{name}

%changelog
* Fri Oct  8 2021 Michał Rostecki <mrostecki@suse.com>
- Update to 0.3.20
  * README.md: update installation instructions (#148)
  * Update Go to 1.17, update dependencies (#150)
* Thu Jun 10 2021 Michał Rostecki <mrostecki@suse.com>
- Update to 0.3.18
  * Support for reporting the percent of CPU time usage within
    given time
  * agent: mention SO_REUSEPORT in Options.ReuseSocketAddrAndPort
    godoc
* Tue Jul 10 2018 mrostecki@suse.com
- Update to 0.3.4
  * vendor: dep ensure -update github.com/shirou/gopsutil (#79)
    gopsutil library is licensed under BSD, but the previous
    version contained some GPL-licensed code which is a violation
    of GPL license. The updated version doesn't contain
    GPL-licensed code anymore.
    https://github.com/shirou/gopsutil/issues/518
- Make use of golang-packaging macros
* Wed Mar 21 2018 mrostecki@suse.com
- Initial release
